// SPDX-FileCopyrightText: 2019-2024 Tobias Leupold <tl at stonemx dot de>
//
// SPDX-License-Identifier: GPL-3.0-or-later

#ifndef DRAWOVERVIEWPAGE_H
#define DRAWOVERVIEWPAGE_H

// Local includes
#include "shared/OptionalPage.h"
#include "shared/Draw.h"

// Local classes
class SharedObjects;
class TournamentSettings;
class SearchWidget;
class SearchEngine;
class RegistrationsModel;
class DrawModel;
class DrawView;

// Qt classes
class QLabel;

class DrawOverviewPage : public OptionalPage
{
    Q_OBJECT

public:
    explicit DrawOverviewPage(QWidget *parent, SharedObjects *sharedObjects,
                              RegistrationsModel *registrationsModel, bool drawAdjustmentNeeded);

Q_SIGNALS:
    void showAdjustDrawDialog();

public Q_SLOTS:
    void resetSearch();
    void drawAdjustmentNeeded(bool state);
    bool closePage();
    void updateDraw(const QString &scrollTarget = QString());

private Q_SLOTS:
    void updateSearch(const QString &searchText);

private: // Variables
    TournamentSettings *m_tournamentSettings;
    SearchEngine *m_searchEngine;
    RegistrationsModel *m_registrationsModel;

    QLabel *m_uncompletedTablesLabel;
    QLabel *m_noDraw;
    QLabel *m_isSearch;
    DrawModel *m_drawModel;
    DrawView *m_drawView;
    QLabel *m_adjustmentLabel;
    SearchWidget *m_searchWidget;

};

#endif // DRAWOVERVIEWPAGE_H
